@@ -1,3 +1,5 @@
+\donttest{
+
 #compare normally distributed with uniform points
 x<-cbind(1,runif(100,-100,100), runif(100,-100,100))
 x<-rbind(x, cbind(2,rnorm(100,0,20), rnorm(100,0,20)))
@@ -17,7 +19,8 @@ r.mid <- (r.max+r.min)/2
 pi<-get.pi(x,fun,r=r.max,r.low=r.min)
 pi.ci<-get.pi.ci(x,fun,r=r.max,r.low=r.min,boot.iter=100)
 
+plot(r.mid, pi$pi, type="l")
+lines(r.mid, pi.ci[,2] , lty=2)
+lines(r.mid, pi.ci[,3] , lty=2)
 
-plot(r.mid, pi , type="l")
-lines(r.mid, pi.ci[1,] , lty=2)
-lines(r.mid, pi.ci[2,] , lty=2)
+}
\ No newline at end of file
