@@ -1,4 +1,6 @@
-data(DengueSimulationR02)
+\donttest{
+
+data(DengueSimR02)
 
 r.max<-seq(20,1000,20)
 r.min<-seq(0,980,20)
@@ -8,3 +10,5 @@ type<-2-(DengueSimR02[,"time"]<120)
 tmp<-cbind(DengueSimR02,type=type)
 
 typed.pi.bs<-get.pi.typed.bootstrap(tmp,typeA=1,typeB=2,r=r.max,r.low=r.min,boot.iter=100)
+
+}
\ No newline at end of file
