@@ -1,3 +1,5 @@
+\donttest{
+
 #compare normally distributed with uniform points
 x<-cbind(1,runif(100,-100,100), runif(100,-100,100))
 x<-rbind(x, cbind(2,rnorm(100,0,20), rnorm(100,0,20)))
@@ -13,12 +15,13 @@ r.max<-seq(10,100,10)
 r.min<-seq(0,90,10)
 r.mid <- (r.max+r.min)/2
 
-
 theta<-get.theta(x,fun,r=r.max,r.low=r.min)
 theta.null<-get.theta.permute(x,fun,r=r.max,r.low=r.min,permutations=100)
 
-null.ci<-apply(theta.null,2,quantile,probs=c(0.25,0.75))
+null.ci<-apply(theta.null[,-(1:2)],1,quantile,probs=c(0.25,0.75))
 
-plot(r.mid, theta , type="l")
+plot(r.mid, theta$theta , type="l")
 lines(r.mid, null.ci[1,] , lty=2)
 lines(r.mid, null.ci[2,] , lty=2)
+
+}
\ No newline at end of file
